# fancy-collections

This package provide some useful classes to store data in a structured way.
Up to now mostly advanced dictionaries are provided. 


## Installation and requirements

*fancy-collections* requires Python 3.7+ to run and can be installed by running 
```bash
pip install fancy-collections
```

## Usage

```pycon
>>> from fancy_collections import SliceDict, DictOfPandas, DictOfSeries
```

See also
--------
- https://pypi.org/project/sliceable-dict/